pub trait RemoteImportTarget: ErasedCallTarget {
// Required method
fn supports_capability(&self, capability: &CapabilityId) -> bool;
}Expand description
A configured remote target that can prove which exact capabilities it supports.
Required Methods
Sourcefn supports_capability(&self, capability: &CapabilityId) -> bool
fn supports_capability(&self, capability: &CapabilityId) -> bool
Reports whether the target supports this exact capability identity.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".