pub struct TransportRuntime<C>{ /* private fields */ }Expand description
Per-binding state whose activation gate commits startup, not call cancellation.
Implementations
Sourceimpl<C: Send + Sync + 'static> TransportRuntime<C>
impl<C: Send + Sync + 'static> TransportRuntime<C>
Sourcepub fn exposures(&self) -> &[TransportExposure]
pub fn exposures(&self) -> &[TransportExposure]
Returns exposures in builder-call order.
Sourcepub fn tracker(&self) -> &TransportTaskTracker
pub fn tracker(&self) -> &TransportTaskTracker
Returns the composition-owned tracker shared by all bindings.
Sourcepub fn is_active(&self) -> bool
pub fn is_active(&self) -> bool
Returns whether startup has committed and traffic may be admitted.
Sourcepub async fn wait_until_active(&self)
pub async fn wait_until_active(&self)
Waits until startup commits and traffic may be admitted.