RemoteImportTarget

Trait RemoteImportTarget 

pub trait RemoteImportTarget: ErasedCallTarget {
    // Required method
    fn supports_capability(&self, capability: &CapabilityId) -> bool;
}
A configured remote target that can prove which exact capabilities it supports.

Required Methods

fn supports_capability(&self, capability: &CapabilityId) -> bool

Reports whether the target supports this exact capability identity.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors